==> lightdash_client_python-0.618.0.tar.gz: lightdash_client_python-0.618.0/lightdash_client/models/api_error_payload.py <==
from typing import Any
from typing import Dict
from typing import List
from typing import Type
from typing import TYPE_CHECKING
from typing import TypeVar

import attr

from ..models.api_error_payload_status import ApiErrorPayloadStatus

if TYPE_CHECKING:
    from ..models.api_error_payload_error import ApiErrorPayloadError


T = TypeVar("T", bound="ApiErrorPayload")


@attr.s(auto_attribs=True)
class ApiErrorPayload:
    """The Error object is returned from the api any time there is an error.
    The message contains

        Attributes:
            error (ApiErrorPayloadError):
            status (ApiErrorPayloadStatus):
    """

    error: "ApiErrorPayloadError"
    status: ApiErrorPayloadStatus
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        error = self.error.to_dict()

        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "error": error,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.api_error_payload_error import ApiErrorPayloadError

        d = src_dict.copy()
        error = ApiErrorPayloadError.from_dict(d.pop("error"))

        status = ApiErrorPayloadStatus(d.pop("status"))

        api_error_payload = cls(
            error=error,
            status=status,
        )

        api_error_payload.additional_properties = d
        return api_error_payload

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.651.2.tar.gz: lightdash_client_python-0.651.2/lightdash_client/models/api_error_payload.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

from ..models.api_error_payload_status import ApiErrorPayloadStatus

if TYPE_CHECKING:
    from ..models.api_error_payload_error import ApiErrorPayloadError


T = TypeVar("T", bound="ApiErrorPayload")


@attr.s(auto_attribs=True)
class ApiErrorPayload:
    """The Error object is returned from the api any time there is an error.
    The message contains

        Attributes:
            error (ApiErrorPayloadError):
            status (ApiErrorPayloadStatus):
    """

    error: "ApiErrorPayloadError"
    status: ApiErrorPayloadStatus
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        error = self.error.to_dict()

        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "error": error,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.api_error_payload_error import ApiErrorPayloadError

        d = src_dict.copy()
        error = ApiErrorPayloadError.from_dict(d.pop("error"))

        status = ApiErrorPayloadStatus(d.pop("status"))

        api_error_payload = cls(
            error=error,
            status=status,
        )

        api_error_payload.additional_properties = d
        return api_error_payload

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
